/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2000-2001 by Andreas Zehender
    email                : zehender@kde.org
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/


#include "pmpigmentedit.h"
#include "pmpigment.h"
#include "pmlinkedit.h"

#include <qlayout.h>
#include <qlabel.h>
#include <klocale.h>


PMPigmentEdit::PMPigmentEdit( QWidget* parent, const char* name )
      : Base( parent, name )
{
   m_pDisplayedObject = 0;
}

void PMPigmentEdit::displayObject( PMObject* o )
{
   if( o->isA( "Pigment" ) )
   {
      Base::displayObject( o );
   }
   else
      kdError( PMArea ) << "PMPigmentEdit: Can't display object\n";
}

#include "pmpigmentedit.moc"
